pub struct ModifyLiquidityOneSide {
pub position: Pubkey,
pub lb_pair: Pubkey,
pub bin_array_bitmap_extension: Option<Pubkey>,
pub user_token: Pubkey,
pub reserve: Pubkey,
pub token_mint: Pubkey,
pub bin_array_lower: Pubkey,
pub bin_array_upper: Pubkey,
pub sender: Pubkey,
pub token_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for ModifyLiquidityOneSide.
Fields
position: Pubkeylb_pair: Pubkeybin_array_bitmap_extension: Option<Pubkey>user_token: Pubkeyreserve: Pubkeytoken_mint: Pubkeybin_array_lower: Pubkeybin_array_upper: Pubkeysender: Pubkeytoken_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl ToAccountMetas for ModifyLiquidityOneSide
impl ToAccountMetas for ModifyLiquidityOneSide
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ModifyLiquidityOneSide
impl RefUnwindSafe for ModifyLiquidityOneSide
impl Send for ModifyLiquidityOneSide
impl Sync for ModifyLiquidityOneSide
impl Unpin for ModifyLiquidityOneSide
impl UnsafeUnpin for ModifyLiquidityOneSide
impl UnwindSafe for ModifyLiquidityOneSide