pub struct SetLockReleaseSlot {
pub position: Pubkey,
pub lb_pair: Pubkey,
pub sender: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for SetLockReleaseSlot.
Fields
position: Pubkeylb_pair: Pubkeysender: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetLockReleaseSlotwhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetLockReleaseSlotwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetLockReleaseSlot
impl ToAccountMetas for SetLockReleaseSlot
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetLockReleaseSlot
impl RefUnwindSafe for SetLockReleaseSlot
impl Send for SetLockReleaseSlot
impl Sync for SetLockReleaseSlot
impl Unpin for SetLockReleaseSlot
impl UnsafeUnpin for SetLockReleaseSlot
impl UnwindSafe for SetLockReleaseSlot