pub struct UpdateRewardDuration {
pub lb_pair: Pubkey,
pub reward_index: u64,
pub old_reward_duration: u64,
pub new_reward_duration: u64,
}Fields
lb_pair: Pubkeyreward_index: u64old_reward_duration: u64new_reward_duration: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateRewardDuration
impl BorshDeserialize for UpdateRewardDuration
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for UpdateRewardDuration
impl Discriminator for UpdateRewardDuration
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]