pub struct SetLockReleaseSlot {
pub new_lock_release_slot: u64,
}Expand description
Instruction.
Fields
new_lock_release_slot: u64Trait Implementations
Sourceimpl BorshDeserialize for SetLockReleaseSlotwhere
u64: BorshDeserialize,
impl BorshDeserialize for SetLockReleaseSlotwhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetLockReleaseSlotwhere
u64: BorshSerialize,
impl BorshSerialize for SetLockReleaseSlotwhere
u64: BorshSerialize,
Sourceimpl Discriminator for SetLockReleaseSlot
impl Discriminator for SetLockReleaseSlot
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for SetLockReleaseSlot
impl InstructionData for SetLockReleaseSlot