#[repr(C)]pub struct VariableParameters {
pub volatility_accumulator: u32,
pub volatility_reference: u32,
pub index_reference: i32,
pub _padding: [u8; 4],
pub last_update_timestamp: i64,
pub _padding_1: [u8; 8],
}Expand description
Parameters that changes based on dynamic of the market
Fields
volatility_accumulator: u32Volatility accumulator measure the number of bin crossed since reference bin ID. Normally (without filter period taken into consideration), reference bin ID is the active bin of last swap. It affects the variable fee rate
volatility_reference: u32Volatility reference is decayed volatility accumulator. It is always <= volatility_accumulator
index_reference: i32Active bin id of last swap.
_padding: [u8; 4]Padding for bytemuck safe alignment
last_update_timestamp: i64Last timestamp the variable parameters was updated
_padding_1: [u8; 8]Padding for bytemuck safe alignment
Implementations
Sourceimpl VariableParameters
impl VariableParameters
Sourcepub fn update_volatility_accumulator(
&mut self,
active_id: i32,
static_params: &StaticParameters,
) -> Result<()>
pub fn update_volatility_accumulator( &mut self, active_id: i32, static_params: &StaticParameters, ) -> Result<()>
volatility_accumulator = min(volatility_reference + num_of_bin_crossed, max_volatility_accumulator)
Sourcepub fn update_references(
&mut self,
active_id: i32,
current_timestamp: i64,
static_params: &StaticParameters,
) -> Result<()>
pub fn update_references( &mut self, active_id: i32, current_timestamp: i64, static_params: &StaticParameters, ) -> Result<()>
Update id, and volatility reference
pub fn update_volatility_parameter( &mut self, active_id: i32, current_timestamp: i64, static_params: &StaticParameters, ) -> Result<()>